==> math-base-assert-is-nanf-0.0.3.tgz: package/README.md <==
<!--

@license Apache-2.0

Copyright (c) 2020 The Stdlib Authors.

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

   http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.

-->

# isnanf

[![NPM version][npm-image]][npm-url] [![Build Status][test-image]][test-url] [![Coverage Status][coverage-image]][coverage-url] [![dependencies][dependencies-image]][dependencies-url]

> Test if a single-precision floating-point numeric value is NaN.

<section class="installation">

## Installation

```bash
npm install @stdlib/math-base-assert-is-nanf
```

</section>

<section class="usage">

## Usage

```javascript
var isnanf = require( '@stdlib/math-base-assert-is-nanf' );
```

#### isnanf( x )

Tests if a single-precision floating-point `numeric` value is `NaN`.

```javascript
var bool = isnanf( NaN );
// returns true
```

</section>

<!-- /.usage -->

<section class="examples">

## Examples

<!-- eslint no-undef: "error" -->

```javascript
var isnanf = require( '@stdlib/math-base-assert-is-nanf' );

var bool = isnanf( NaN );
// returns true

bool = isnanf( 5.0 );
// returns false
```

</section>

<!-- /.examples -->


<section class="main-repo" >

* * *

## Notice

This package is part of [stdlib][stdlib], a standard library for JavaScript and Node.js, with an emphasis on numerical and scientific computing. The library provides a collection of robust, high performance libraries for mathematics, statistics, streams, utilities, and more.

For more information on the project, filing bug reports and feature requests, and guidance on how to develop [stdlib][stdlib], see the main project [repository][stdlib].

---

## License

See [LICENSE][stdlib-license].


## Copyright

Copyright &copy; 2016-2021. The Stdlib [Authors][stdlib-authors].

</section>

<!-- /.stdlib -->

<!-- Section for all links. Make sure to keep an empty line after the `section` element and another before the `/section` close. -->

<section class="links">

[npm-image]: http://img.shields.io/npm/v/@stdlib/math-base-assert-is-nanf.svg
[npm-url]: https://npmjs.org/package/@stdlib/math-base-assert-is-nanf

[test-image]: https://github.com/stdlib-js/math-base-assert-is-nanf/actions/workflows/test.yml/badge.svg
[test-url]: https://github.com/stdlib-js/math-base-assert-is-nanf/actions/workflows/test.yml

[coverage-image]: https://img.shields.io/codecov/c/github/stdlib-js/math-base-assert-is-nanf/main.svg
[coverage-url]: https://codecov.io/github/stdlib-js/math-base-assert-is-nanf?branch=main

[dependencies-image]: https://img.shields.io/david/stdlib-js/math-base-assert-is-nanf
[dependencies-url]: https://david-dm.org/stdlib-js/math-base-assert-is-nanf/main

[stdlib]: https://github.com/stdlib-js/stdlib

[stdlib-authors]: https://github.com/stdlib-js/stdlib/graphs/contributors

[stdlib-license]: https://raw.githubusercontent.com/stdlib-js/math-base-assert-is-nanf/main/LICENSE

</section>

<!-- /.links -->

==> math-base-assert-is-nanf-0.0.7.tgz: package/README.md <==
<!--

@license Apache-2.0

Copyright (c) 2020 The Stdlib Authors.

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

   http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.

-->

# isnanf

[![NPM version][npm-image]][npm-url] [![Build Status][test-image]][test-url] [![Coverage Status][coverage-image]][coverage-url] [![dependencies][dependencies-image]][dependencies-url]

> Test if a single-precision floating-point numeric value is NaN.

<section class="installation">

## Installation

```bash
npm install @stdlib/math-base-assert-is-nanf
```

</section>

<section class="usage">

## Usage

```javascript
var isnanf = require( '@stdlib/math-base-assert-is-nanf' );
```

#### isnanf( x )

Tests if a single-precision floating-point `numeric` value is `NaN`.

```javascript
var bool = isnanf( NaN );
// returns true
```

</section>

<!-- /.usage -->

<section class="examples">

## Examples

<!-- eslint no-undef: "error" -->

```javascript
var isnanf = require( '@stdlib/math-base-assert-is-nanf' );

var bool = isnanf( NaN );
// returns true

bool = isnanf( 5.0 );
// returns false
```

</section>

<!-- /.examples -->


<section class="main-repo" >

* * *

## Notice

This package is part of [stdlib][stdlib], a standard library for JavaScript and Node.js, with an emphasis on numerical and scientific computing. The library provides a collection of robust, high performance libraries for mathematics, statistics, streams, utilities, and more.

For more information on the project, filing bug reports and feature requests, and guidance on how to develop [stdlib][stdlib], see the main project [repository][stdlib].

#### Community

[![Chat][chat-image]][chat-url]

---

## License

See [LICENSE][stdlib-license].


## Copyright

Copyright &copy; 2016-2021. The Stdlib [Authors][stdlib-authors].

</section>

<!-- /.stdlib -->

<!-- Section for all links. Make sure to keep an empty line after the `section` element and another before the `/section` close. -->

<section class="links">

[npm-image]: http://img.shields.io/npm/v/@stdlib/math-base-assert-is-nanf.svg
[npm-url]: https://npmjs.org/package/@stdlib/math-base-assert-is-nanf

[test-image]: https://github.com/stdlib-js/math-base-assert-is-nanf/actions/workflows/test.yml/badge.svg
[test-url]: https://github.com/stdlib-js/math-base-assert-is-nanf/actions/workflows/test.yml

[coverage-image]: https://img.shields.io/codecov/c/github/stdlib-js/math-base-assert-is-nanf/main.svg
[coverage-url]: https://codecov.io/github/stdlib-js/math-base-assert-is-nanf?branch=main

[dependencies-image]: https://img.shields.io/david/stdlib-js/math-base-assert-is-nanf.svg
[dependencies-url]: https://david-dm.org/stdlib-js/math-base-assert-is-nanf/main

[chat-image]: https://img.shields.io/gitter/room/stdlib-js/stdlib.svg
[chat-url]: https://gitter.im/stdlib-js/stdlib/

[stdlib]: https://github.com/stdlib-js/stdlib

[stdlib-authors]: https://github.com/stdlib-js/stdlib/graphs/contributors

[stdlib-license]: https://raw.githubusercontent.com/stdlib-js/math-base-assert-is-nanf/main/LICENSE

</section>

<!-- /.links -->
